@@ -12,6 +12,7 @@
 #include <QScreen>
 
 #include <KLocalizedString>
+#include <KWindowSystem>
 
 #include <ModemManagerQt/Manager>
 
@@ -129,7 +130,7 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
     ui->pin->setCursorPosition(0);
     ui->pin2->setCursorPosition(0);
 
-    setWindowFlag(Qt::WindowStaysOnTopHint);
+    KWindowSystem::setState(winId(), NET::KeepAbove);
 
     move((desktop.width() - width()) / 2, (desktop.height() - height()) / 2);
     connect(ui->chkShowPass, &QCheckBox::toggled, this, &PinDialog::chkShowPassToggled);
