@@ -13,6 +13,7 @@
 
 class Q_DECL_EXPORT SimpleIpListValidator : public QValidator
 {
+    Q_OBJECT
 public:
     enum AddressType { Ipv4, Ipv6, Both };
     enum AddressStyle { Base, WithCidr, WithPort };
@@ -23,8 +24,8 @@ public:
     State validate(QString &, int &) const override;
 
 private:
-    SimpleIpV6AddressValidator *m_ipv6Validator;
-    SimpleIpV4AddressValidator *m_ipv4Validator;
+    SimpleIpV6AddressValidator *m_ipv6Validator = nullptr;
+    SimpleIpV4AddressValidator *m_ipv4Validator = nullptr;
 };
 
 #endif // SIMPLEIPV4ADDRESSVALIDATOR_H
